/*
 * IcmpStatus.java 
 *
 * Copyright (c) Verax Systems.
 * All rights reserved.
 *
 * This software is furnished under a license. Use, duplication,
 * disclosure and all other uses are restricted to the rights
 * specified in the written license agreement.
 */
package com.veraxsystems.icmp;

/**
 * The set of expected ICMP response statuses. They are mapped directly to 
 * ICMP response types/codes as defined in RFC792, RFC1256, RFC950, 
 * RFC1393, RFC1475, RFC1788, RFC2521, RFC4065.
 * The interpretation is:
 * <ul>
 *   <li> <code>EchoReply</code> - successful response from host
 *   <li> <code>UnexpectedResponse</code> - unknown response or response not received
 *   <li> <i>other values</i> - network has rejected ICMP echo request
 * </ul>
 */
public enum IcmpStatus 
{
   EchoReply(0 * 256 +  0),
   NetUnreachable(3 * 256 + 0),
   HostUnreachable(3 * 256 + 1),
   ProtocolUnreachable(3 * 256 + 2),
   PortUnreachable(3 * 256 + 3),
   FragmentationNeeded(3 * 256 + 4),
   SourceRouteFailed(3 * 256 + 5),
   DestinationNetworkUnknown(3 * 256 + 6),
   DestinationHostUnknown(3 * 256 + 7),
   SourceHostIsolated(3 * 256 + 8),
   DestinationNetworkProhibited(3 * 256 + 9),
   DestinationHostProhibited(3 * 256 + 10),
   DestinationNetworkUnreachableForService(3 * 256 + 11),
   DestinationHostUnreachableFforService(3 * 256 + 12),
   CommunicationProhibited(3 * 256 + 13),
   HostPrecedenceViolation(3 * 256 + 14),
   PrecedenceCutoffInEffect(3 * 256 + 15),
   SourceQuench(4 * 256 +  0),
   RedirectDatagramForNetwork(5 * 256 +  0),
   RedirectDatagramForHost(5 * 256 +  1),
   RedirectDatagramTypeServiceNetwork(5 * 256 +  2),
   RedirectDatagramTypeServiceHost(5 * 256 +  3),
   TimeToLiveExceeded(11 * 256 +  0),
   FragmentReassemblyTimeExceeded(11 * 256 +  1),
   MessageParameterProblem(12 * 256 +  0),
   MissingRequiredMessageOption(12 * 256 +  1),
   BadMessageLength(12 * 256 +  2),
   DatagramConverionError(31 * 256 +  0),
   UnexpectedResponse(Integer.MAX_VALUE);
   
   private int value;

   private IcmpStatus(int code) {
      value = code;
   }
   
   /**
    * Get integer code of enumeration
    * @return integer code 
    */
   public int getValue() {
      return value;
   }

}
