/*
 * PingExampleSync.java 
 *
 * Copyright (c) Verax Systems.
 * All rights reserved.
 *
 * This software is furnished under a license. Use, duplication,
 * disclosure and all other uses are restricted to the rights
 * specified in the written license agreement.
 */
package com.veraxsystems.icmp.ping.example;

import com.veraxsystems.icmp.ping.Ping;
import com.veraxsystems.icmp.ping.PingResult;
import com.veraxsystems.icmp.ping.exception.PingErrorException;

import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.UnknownHostException;

/**
 * The example program for {link Ping} class.
 * It accepts command line parameters and issues synchronous ICMP echo request. 
 * Results of requests are displayed on the screen.
 */
public class PingExampleSync
{

   static {
       com.veraxsystems.icmp.jni.IcmpJniBridge.loadNativeLibrary();       
   }
 
   public static void main(String[] args) 
   {
      if (args.length >= 2)
      {
         try
         {
            InetAddress[] addresses = new Inet4Address[args.length - 1];
            int timeout = Integer.parseInt(args[0]);
            PingResult[] results = null;
            int requestsNumber = 0;
            
            // Initialize Ping
            Ping.init();
            
            // Get names of hosts so it is easy to use CountDownLatch 
            for(int i = 1; i < args.length; i++)
            {
               try 
               {
                  addresses[requestsNumber] = Inet4Address.getByName(args[i]);
                  requestsNumber += 1;
               } 
               catch (UnknownHostException ex) 
               {
                  System.out.println("Unknown host: " + args[i]);
               }
            };
            
            try
            {
               // Send echo requests to all addresses
               results = Ping.echo(addresses, "DATA".getBytes(), timeout);
               
               // Print results of processing
               DisplayResults(results);
            }
            catch(PingErrorException ex)
            {
               // Fatal error occured in echo method - exit program
               System.out.println("Fatal error - terminating " + ex.toString());
            }
         } 
         catch (PingErrorException ex) 
         {
            System.out.println("Could not initialize Ping class: " + ex.toString());
         }
         finally
         {
            // Release Ping 
            Ping.release();
         }
      }
      else
      {
         System.out.println("Usage:");
         System.out.println("     Ping <timeout> <address list>");
         System.out.println("");
      }
   }

   private static void DisplayResults(PingResult[] results) 
   {
      for(int i = 0; i < results.length; i++)
      {
         switch(results[i].getResult())
         {
            case Response : 
               System.out.println(results[i].getAddress().getHostAddress() + " response: " + results[i].getStatus() + " time:" + results[i].getResponseTime());
               break;
            case Timeout :
               System.out.println(results[i].getAddress().getHostAddress() + " timeout");
               break;
            case Error : 
               System.out.println(results[i].getAddress().getHostAddress() + "ping error");
               break;
         }
      }
   }
}
